==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/upse.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	upse.lang.inc.php 2018-02-16
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_SHIPPING_UPSE_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, in welche ein Versand möglich sein soll, z. B.: AT,DE.',
	'MODULE_SHIPPING_UPSE_ALLOWED_TITLE' => 'Einzelne Versandzonen',
	'MODULE_SHIPPING_UPSE_COST_10_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 8. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 80,05 = 0.5:80.05,...',
	'MODULE_SHIPPING_UPSE_COST_10_TITLE' => 'Tarife für UPS Express Zone 8',
	'MODULE_SHIPPING_UPSE_COST_11_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 9. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 85,20 = 0.5:85.20,...',
	'MODULE_SHIPPING_UPSE_COST_11_TITLE' => 'Tarife für UPS Express Zone 9',
	'MODULE_SHIPPING_UPSE_COST_12_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 10. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 93,10 = 0.5:93.10,...',
	'MODULE_SHIPPING_UPSE_COST_12_TITLE' => 'Tarife für UPS Express Zone 10',
	'MODULE_SHIPPING_UPSE_COST_13_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 11. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 103,50 = 0.5:103.50,...',
	'MODULE_SHIPPING_UPSE_COST_13_TITLE' => 'Tarife für UPS Express Zone 11',
	'MODULE_SHIPPING_UPSE_COST_14_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 12. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 105,20 = 0.5:105.20,...',
	'MODULE_SHIPPING_UPSE_COST_14_TITLE' => 'Tarife für UPS Express Zone 12',
	'MODULE_SHIPPING_UPSE_COST_1_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 1. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 22,70 = 0.5:22.7,...',
	'MODULE_SHIPPING_UPSE_COST_1_TITLE' => 'Tarife für UPS Express Zone 1',
	'MODULE_SHIPPING_UPSE_COST_2_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 2. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 51,55 = 0.5:51.55,...',
	'MODULE_SHIPPING_UPSE_COST_2_TITLE' => 'Tarife für UPS Express Zone 2',
	'MODULE_SHIPPING_UPSE_COST_3_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 3. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 60,70 = 0.5:60.70,...',
	'MODULE_SHIPPING_UPSE_COST_3_TITLE' => 'Tarife für UPS Express Zone 3',
	'MODULE_SHIPPING_UPSE_COST_4_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 4. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 66,90 = 0.5:66.90,...',
	'MODULE_SHIPPING_UPSE_COST_4_TITLE' => 'Tarife für UPS Express Zone 4',
	'MODULE_SHIPPING_UPSE_COST_5_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 41. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 82,10 = 0.5:82.10,...',
	'MODULE_SHIPPING_UPSE_COST_5_TITLE' => 'Tarife für UPS Express Zone 41',
	'MODULE_SHIPPING_UPSE_COST_6_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 42. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 82,90 = 0.5:82.90,...',
	'MODULE_SHIPPING_UPSE_COST_6_TITLE' => 'Tarife für UPS Express Zone 42',
	'MODULE_SHIPPING_UPSE_COST_7_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 5. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 59,00 = 0.5:59.00,...',
	'MODULE_SHIPPING_UPSE_COST_7_TITLE' => 'Tarife für UPS Express Zone 5',
	'MODULE_SHIPPING_UPSE_COST_8_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 6. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 84,50 = 0.5:84.50,...',
	'MODULE_SHIPPING_UPSE_COST_8_TITLE' => 'Tarife für UPS Express Zone 6',
	'MODULE_SHIPPING_UPSE_COST_9_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 7. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 71,85 = 0.5:71.85,...',
	'MODULE_SHIPPING_UPSE_COST_9_TITLE' => 'Tarife für UPS Express Zone 7',
	'MODULE_SHIPPING_UPSE_COUNTRIES_10_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 8:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_10_TITLE' => 'Staaten für UPS Express Zone 8',
	'MODULE_SHIPPING_UPSE_COUNTRIES_11_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 9:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_11_TITLE' => 'Staaten für UPS Express Zone 9',
	'MODULE_SHIPPING_UPSE_COUNTRIES_12_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 10:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_12_TITLE' => 'Staaten für UPS Express Zone 10',
	'MODULE_SHIPPING_UPSE_COUNTRIES_13_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 11:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_13_TITLE' => 'Staaten für UPS Express Zone 11',
	'MODULE_SHIPPING_UPSE_COUNTRIES_14_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 12:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_14_TITLE' => 'Staaten für UPS Express Zone 12',
	'MODULE_SHIPPING_UPSE_COUNTRIES_1_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 1:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_1_TITLE' => 'Staaten für UPS Express Zone 1',
	'MODULE_SHIPPING_UPSE_COUNTRIES_2_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 2:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_2_TITLE' => 'Staaten für UPS Express Zone 2',
	'MODULE_SHIPPING_UPSE_COUNTRIES_3_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 3:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_3_TITLE' => 'Staaten für UPS Express Zone 3',
	'MODULE_SHIPPING_UPSE_COUNTRIES_4_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 4:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_4_TITLE' => 'Staaten für UPS Express Zone 4',
	'MODULE_SHIPPING_UPSE_COUNTRIES_5_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 41:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_5_TITLE' => 'Staaten für UPS Express Zone 41',
	'MODULE_SHIPPING_UPSE_COUNTRIES_6_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 42:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_6_TITLE' => 'Staaten für UPS Express Zone 42',
	'MODULE_SHIPPING_UPSE_COUNTRIES_7_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 5:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_7_TITLE' => 'Staaten für UPS Express Zone 5',
	'MODULE_SHIPPING_UPSE_COUNTRIES_8_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 6:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_8_TITLE' => 'Staaten für UPS Express Zone 6',
	'MODULE_SHIPPING_UPSE_COUNTRIES_9_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 7:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_9_TITLE' => 'Staaten für UPS Express Zone 7',
	'MODULE_SHIPPING_UPSE_HANDLING_DESC' => 'Bearbeitungszuschlag für diese Versandart in Euro',
	'MODULE_SHIPPING_UPSE_HANDLING_TITLE' => 'Zuschlag',
	'MODULE_SHIPPING_UPSE_INVALID_ZONE' => 'Diese Option steht für ihre Lieferadresse nicht zur Verfügung',
	'MODULE_SHIPPING_UPSE_SORT_ORDER_DESC' => 'Niedrigste wird zuerst angezeigt.',
	'MODULE_SHIPPING_UPSE_SORT_ORDER_TITLE' => 'Reihenfolge der Anzeige',
	'MODULE_SHIPPING_UPSE_STATUS_DESC' => 'Wollen Sie den Versand durch UPS Express anbieten?',
	'MODULE_SHIPPING_UPSE_STATUS_TITLE' => 'UPS Express',
	'MODULE_SHIPPING_UPSE_TAX_CLASS_DESC' => 'Wählen Sie den MwSt.-Satz für diese Versandart aus.',
	'MODULE_SHIPPING_UPSE_TAX_CLASS_TITLE' => 'Steuersatz',
	'MODULE_SHIPPING_UPSE_TEXT_DESCRIPTION' => 'United Parcel Service Express - Versandmodul',
	'MODULE_SHIPPING_UPSE_TEXT_TITLE' => 'United Parcel Service Express',
	'MODULE_SHIPPING_UPSE_TEXT_UNITS' => 'kg',
	'MODULE_SHIPPING_UPSE_TEXT_WAY' => 'Versand nach',
	'MODULE_SHIPPING_UPSE_UNDEFINED_RATE' => 'Die Versandkosten können im Moment nicht errechnet werden.',
	'MODULE_SHIPPING_UPSE_ZONE_DESC' => 'Wenn Sie eine Zone auswählen, wird diese Versandart nur in dieser Zone angeboten.',
	'MODULE_SHIPPING_UPSE_ZONE_TITLE' => 'Versand Zone'
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/upse.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	upse.lang.inc.php 2018-02-16
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2018 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_SHIPPING_UPSE_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, in welche ein Versand möglich sein soll, z. B.: AT,DE.',
	'MODULE_SHIPPING_UPSE_ALLOWED_TITLE' => 'Einzelne Versandzonen',
	'MODULE_SHIPPING_UPSE_COST_10_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 8. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 80,05 = 0.5:80.05,...',
	'MODULE_SHIPPING_UPSE_COST_10_TITLE' => 'Tarife für UPS Express Zone 8',
	'MODULE_SHIPPING_UPSE_COST_11_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 9. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 85,20 = 0.5:85.20,...',
	'MODULE_SHIPPING_UPSE_COST_11_TITLE' => 'Tarife für UPS Express Zone 9',
	'MODULE_SHIPPING_UPSE_COST_12_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 10. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 93,10 = 0.5:93.10,...',
	'MODULE_SHIPPING_UPSE_COST_12_TITLE' => 'Tarife für UPS Express Zone 10',
	'MODULE_SHIPPING_UPSE_COST_13_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 11. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 103,50 = 0.5:103.50,...',
	'MODULE_SHIPPING_UPSE_COST_13_TITLE' => 'Tarife für UPS Express Zone 11',
	'MODULE_SHIPPING_UPSE_COST_14_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 12. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 105,20 = 0.5:105.20,...',
	'MODULE_SHIPPING_UPSE_COST_14_TITLE' => 'Tarife für UPS Express Zone 12',
	'MODULE_SHIPPING_UPSE_COST_1_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 1. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 22,70 = 0.5:22.7,...',
	'MODULE_SHIPPING_UPSE_COST_1_TITLE' => 'Tarife für UPS Express Zone 1',
	'MODULE_SHIPPING_UPSE_COST_2_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 2. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 51,55 = 0.5:51.55,...',
	'MODULE_SHIPPING_UPSE_COST_2_TITLE' => 'Tarife für UPS Express Zone 2',
	'MODULE_SHIPPING_UPSE_COST_3_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 3. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 60,70 = 0.5:60.70,...',
	'MODULE_SHIPPING_UPSE_COST_3_TITLE' => 'Tarife für UPS Express Zone 3',
	'MODULE_SHIPPING_UPSE_COST_4_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 4. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 66,90 = 0.5:66.90,...',
	'MODULE_SHIPPING_UPSE_COST_4_TITLE' => 'Tarife für UPS Express Zone 4',
	'MODULE_SHIPPING_UPSE_COST_5_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 41. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 82,10 = 0.5:82.10,...',
	'MODULE_SHIPPING_UPSE_COST_5_TITLE' => 'Tarife für UPS Express Zone 41',
	'MODULE_SHIPPING_UPSE_COST_6_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 42. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 82,90 = 0.5:82.90,...',
	'MODULE_SHIPPING_UPSE_COST_6_TITLE' => 'Tarife für UPS Express Zone 42',
	'MODULE_SHIPPING_UPSE_COST_7_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 5. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 59,00 = 0.5:59.00,...',
	'MODULE_SHIPPING_UPSE_COST_7_TITLE' => 'Tarife für UPS Express Zone 5',
	'MODULE_SHIPPING_UPSE_COST_8_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 6. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 84,50 = 0.5:84.50,...',
	'MODULE_SHIPPING_UPSE_COST_8_TITLE' => 'Tarife für UPS Express Zone 6',
	'MODULE_SHIPPING_UPSE_COST_9_DESC' => 'Gewichtsbasierte Versandkosten innerhalb Zone 7. Beispiel: Sendung zwischen 0 und 0,5kg kostet EUR 71,85 = 0.5:71.85,...',
	'MODULE_SHIPPING_UPSE_COST_9_TITLE' => 'Tarife für UPS Express Zone 7',
	'MODULE_SHIPPING_UPSE_COUNTRIES_10_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 8:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_10_TITLE' => 'Staaten für UPS Express Zone 8',
	'MODULE_SHIPPING_UPSE_COUNTRIES_11_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 9:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_11_TITLE' => 'Staaten für UPS Express Zone 9',
	'MODULE_SHIPPING_UPSE_COUNTRIES_12_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 10:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_12_TITLE' => 'Staaten für UPS Express Zone 10',
	'MODULE_SHIPPING_UPSE_COUNTRIES_13_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 11:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_13_TITLE' => 'Staaten für UPS Express Zone 11',
	'MODULE_SHIPPING_UPSE_COUNTRIES_14_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 12:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_14_TITLE' => 'Staaten für UPS Express Zone 12',
	'MODULE_SHIPPING_UPSE_COUNTRIES_1_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 1:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_1_TITLE' => 'Staaten für UPS Express Zone 1',
	'MODULE_SHIPPING_UPSE_COUNTRIES_2_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 2:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_2_TITLE' => 'Staaten für UPS Express Zone 2',
	'MODULE_SHIPPING_UPSE_COUNTRIES_3_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 3:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_3_TITLE' => 'Staaten für UPS Express Zone 3',
	'MODULE_SHIPPING_UPSE_COUNTRIES_4_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 4:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_4_TITLE' => 'Staaten für UPS Express Zone 4',
	'MODULE_SHIPPING_UPSE_COUNTRIES_5_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 41:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_5_TITLE' => 'Staaten für UPS Express Zone 41',
	'MODULE_SHIPPING_UPSE_COUNTRIES_6_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 42:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_6_TITLE' => 'Staaten für UPS Express Zone 42',
	'MODULE_SHIPPING_UPSE_COUNTRIES_7_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 5:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_7_TITLE' => 'Staaten für UPS Express Zone 5',
	'MODULE_SHIPPING_UPSE_COUNTRIES_8_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 6:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_8_TITLE' => 'Staaten für UPS Express Zone 6',
	'MODULE_SHIPPING_UPSE_COUNTRIES_9_DESC' => 'Durch Komma getrennte ISO-Kürzel der Staaten für Zone 7:',
	'MODULE_SHIPPING_UPSE_COUNTRIES_9_TITLE' => 'Staaten für UPS Express Zone 7',
	'MODULE_SHIPPING_UPSE_HANDLING_DESC' => 'Bearbeitungszuschlag für diese Versandart in Euro',
	'MODULE_SHIPPING_UPSE_HANDLING_TITLE' => 'Zuschlag',
	'MODULE_SHIPPING_UPSE_INVALID_ZONE' => 'Diese Option steht für ihre Lieferadresse nicht zur Verfügung',
	'MODULE_SHIPPING_UPSE_SORT_ORDER_DESC' => 'Niedrigste wird zuerst angezeigt.',
	'MODULE_SHIPPING_UPSE_SORT_ORDER_TITLE' => 'Reihenfolge der Anzeige',
	'MODULE_SHIPPING_UPSE_STATUS_DESC' => 'Willst du den Versand durch UPS Express anbieten?',
	'MODULE_SHIPPING_UPSE_STATUS_TITLE' => 'UPS Express',
	'MODULE_SHIPPING_UPSE_TAX_CLASS_DESC' => 'Wähle den MwSt.-Satz für diese Versandart aus.',
	'MODULE_SHIPPING_UPSE_TAX_CLASS_TITLE' => 'Steuersatz',
	'MODULE_SHIPPING_UPSE_TEXT_DESCRIPTION' => 'United Parcel Service Express - Versandmodul',
	'MODULE_SHIPPING_UPSE_TEXT_TITLE' => 'United Parcel Service Express',
	'MODULE_SHIPPING_UPSE_TEXT_UNITS' => 'kg',
	'MODULE_SHIPPING_UPSE_TEXT_WAY' => 'Versand nach',
	'MODULE_SHIPPING_UPSE_UNDEFINED_RATE' => 'Die Versandkosten können im Moment nicht errechnet werden.',
	'MODULE_SHIPPING_UPSE_ZONE_DESC' => 'Wenn du eine Zone auswählst, wird diese Versandart nur in dieser Zone angeboten.',
	'MODULE_SHIPPING_UPSE_ZONE_TITLE' => 'Versand Zone'
);
